import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="molecule-galaxy-wrapper",
    version="0.0.1",
    author="Bernardo Vale",
    author_email="bernardosilveiravale@gmail.com",
    description="A wrapper for ansible-galaxy that allows you to define role dependencies inside a requirements.yml",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bernardoVale/molecule-galaxy-wrapper",
    packages=setuptools.find_packages(),
    scripts=[
        "bin/galaxywrapper"
    ],
    entry_points={
        'console_scripts': ['molecule-galaxy-wrapper=molecule_wrapper.cli:main'],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
